# DORBAN, Diffusion Of Reactors By Analysing Nodes

## Installation

This package uses slepc4py, so one has to have that installed.
Installing slepc, petsc and their wrappers is somewhat convoluted.
The best way to handle this is to install them with conda or mamba.

We are working on a PyPI distribution of our code, but we will try to
build it for conda as well, to make things easier for you.

The reason you can't just pip install this and be done is that pip
installation from source takes about an hour for a well-configured
machine.


